@@ -2,7 +2,8 @@
 
 #' Plot cross-validated glmnet alpha
 #' 
-#' Plot of cross-validated glmnet alpha parameter against deviance.
+#' Plot of cross-validated glmnet alpha parameter against deviance for each 
+#' outer CV fold.
 #' 
 #' @param x Fitted "nestcv.glmnet" object
 #' @param col Optional vector of line colours for each fold
@@ -268,9 +269,7 @@ selectCol <- function(x, colIndex) {
 #' Boxplots to show range of model predictors to identify exceptional predictors
 #' with excessively low or high values.
 #'
-#' @param x Either a "nestedcv" object or a character vector of predictors to
-#'   be plotted
-#' @param data matrix of predictors
+#' @param x a "nestedcv" object
 #' @param scheme colour scheme
 #' @param palette palette name (one of `hcl.pals()`) which is passed to
 #'   [hcl.colors]
@@ -283,9 +282,12 @@ selectCol <- function(x, colIndex) {
 #' @importFrom stats formula
 #' @export
 #' 
-boxplot_model <- function(x, data,
+boxplot_model <- function(x,
                           scheme = NULL, palette = "Dark 3", ...) {
-  m <- if (is.character(x)) x else names(coef(x))[-1]
+  data <- x$xsub
+  m <- names(coef(x))
+  if (is.null(m)) m <- x$final_vars
+  m <- m[m != "(Intercept)"]
   df <- data.frame(vars = rep(m, each = nrow(data)), 
                    y = unlist(lapply(m, function(i) data[, i])))
   x_med <- Rfast::colMedians(data[, m])
